package cz.jzitnik.api;

import cz.jzitnik.api.requests.PlayerNameRequest;
import cz.jzitnik.api.responses.UnifiedResponse;
import cz.jzitnik.api.types.Game;
import cz.jzitnik.api.types.Room;
import cz.jzitnik.api.types.TakeItemsResponse;
import cz.jzitnik.api.types.TestGameKeyResponse;
import retrofit2.Call;
import retrofit2.http.Body;
import retrofit2.http.GET;
import retrofit2.http.POST;
import retrofit2.http.Query;

import java.util.List;

public interface ApiService {
    @GET("status")
    Call<UnifiedResponse<String, Error>> status();

    @POST("game/new")
    Call<UnifiedResponse<Game, Error>> newGame();

    @POST("game/players/new")
    Call<UnifiedResponse<String, Error>> newPlayer(
            @Query("gameKey") String gameKey,
            @Body PlayerNameRequest requestBody
    );

    @POST("game/start")
    Call<UnifiedResponse<Object, Error>> startGame(
            @Query("playerKey") String playerKey,
            @Query("gameKey") String gameKey
    );

    @GET("game/test")
    Call<UnifiedResponse<TestGameKeyResponse, Error>> testGameKey(
            @Query("gameKey") String gameKey
    );

    @GET("game/rooms")
    Call<UnifiedResponse<List<Room>, Error>> getAllRooms(
            @Query("playerKey") String playerKey
    );

    @GET("game/rooms/current_room")
    Call<UnifiedResponse<Room, Error>> getCurrentRoom(
            @Query("playerKey") String playerKey
    );

    @POST("game/rooms/move")
    Call<UnifiedResponse<Object, Error>> moveToRoom(
            @Query("playerKey") String playerKey,
            @Query("roomId") Long roomId
    );

    @POST("game/characters/take_items")
    Call<UnifiedResponse<TakeItemsResponse, Error>> takeItems(
            @Query("playerKey") String playerKey,
            @Query("characterId") Long characterId
    );
}
